#========================================================================================
# package      DE_EPAGES::MolliePayments::API::Requests::Profile
# state        public
# description  Helper module for generating MolliePayments profiles requests to epagesj
#========================================================================================
package DE_EPAGES::MolliePayments::API::Requests::Profiles;
use base DE_EPAGES::MolliePayments::API::Requests::BaseRequest;

use URI;
use URI::QueryParam;

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::MolliePayments::API::Requests::Profiles->new( );
#----------------------------------------------------------------------------------------
# description  MolliePayments profiles requests to epagesj helper constructor
#----------------------------------------------------------------------------------------
# input        $hProfilesData | required data to generate profiles requests to epagesj | hash.ref
# return       $Object | new object | DE_EPAGES::MolliePayments::API::Requests::Profiles
#========================================================================================
sub new {
    my $class = shift;
    my ($hProfilesData) = @_;

    my $self = $class->SUPER::new($hProfilesData);

    return $self;
}

#========================================================================================
# function     getEpagesjRequestSuffixUrlPath
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Url = $ProfilesRequest->getEpagesjRequestSuffixUrlPath( $HttpRequestMethod );
#----------------------------------------------------------------------------------------
# description  It returns the Profiles postfix url path from the epagesj endpoint
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $Url | Profiles suffix url path from the epagesj endpoint | string
#========================================================================================
sub getEpagesjRequestSuffixUrlPath {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq 'GET') {
        return '/profiles';
    }
}

#========================================================================================
# function     withFrom
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->withFrom($ProfileId);
#----------------------------------------------------------------------------------------
# description  Set from as part of the query params
#----------------------------------------------------------------------------------------
# return       $Object | new object | DE_EPAGES::MolliePayments::API::Requests::Profiles
#========================================================================================
sub withFrom {
    my $self = shift;
    my ($ProfileId) = @_;

    $self->{'queryParams'}->{'from'} = $ProfileId;

    return $self;
}

#========================================================================================
# function     withLimit
# state        public
#----------------------------------------------------------------------------------------
# syntax       $self->withLimit($Limit);
#----------------------------------------------------------------------------------------
# description  Set limit as part of the query params
#----------------------------------------------------------------------------------------
# return       $Object | new object | DE_EPAGES::MolliePayments::API::Requests::Profiles
#========================================================================================
sub withLimit {
    my $self = shift;
    my ($Limit) = @_;

    $self->{'queryParams'}->{'limit'} = $Limit;

    return $self;
}

#========================================================================================
# function     getHttpHeaders
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hRequestHeader = $self->getHttpHeaders( $HttpRequestMethod );
#----------------------------------------------------------------------------------------
# description  It returns required headers of the Profiles request
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $hRequestHeader | Profiles request headers hash | hash.ref
#========================================================================================
sub getHttpHeaders {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq 'GET') {
        return {
            'X-AccessToken' => $self->{'data'}->{'payment'}->get('AccessToken')
        };
    }
}

#========================================================================================
# function     getQueryParams
# state        public
#----------------------------------------------------------------------------------------
# syntax       $QueryParams = $self->getQueryParams();
#----------------------------------------------------------------------------------------
# description  It returns the query Params of the Methods request
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $QueryParams | Methods request $QueryParams string | string
#========================================================================================
sub getQueryParams {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq 'GET') {
        return $self->{'queryParams'};
    }

}

1;

