#==============================================================================
# package      DE_EPAGES::MolliePayments::Hooks::OrderProcess
# state        private
#==============================================================================
package DE_EPAGES::MolliePayments::Hooks::OrderProcess;

use strict;
use DE_EPAGES::MolliePayments::UI::BasketOrder;
use DE_EPAGES::MolliePayments::API::PaymentStatusService;
use DE_EPAGES::ExternalPayment::API::Log qw ( LogPayment );
use DE_EPAGES::MolliePayments::API::Constants qw (
    PAYMENT_TYPE_MOLLIE_PAYMENTS
    LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS
    PAYMENT_STATUS_PAID
);

#========================================================================================
# function     AfterSaveMultiCheckoutConfirmation
# state        public
#----------------------------------------------------------------------------------------
# syntax       AfterSaveMultiCheckoutConfirmation($hParams);
#----------------------------------------------------------------------------------------
# description  check order payment status and redirect to error or success
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub AfterSaveMultiCheckoutConfirmation {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $Basket = $Servlet->object();

    my $LineItemContainer = $Basket->container();
    return unless ( defined($LineItemContainer));

    my $LineItemPayment = $LineItemContainer->get('Payment');
    return unless ( defined($LineItemPayment));
    return unless ( $LineItemPayment->instanceOf(LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS));

    my $hFormValues = $Servlet->form()->values();
    my $aChangeActions = $hFormValues->{'ChangeAction'};

    return unless ( 'SaveMultiCheckoutConfirmation' ~~ $aChangeActions );

    DE_EPAGES::MolliePayments::UI::BasketOrder->ValidateOrderPaymentStatus($Servlet, $LineItemPayment);

    return;
}

#========================================================================================
# function     OrderCreatedMultiStepCheckout
# state        public
#----------------------------------------------------------------------------------------
# syntax       OrderCreatedMultiStepCheckout($hParams);
#----------------------------------------------------------------------------------------
# description  Set Order to paid
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Order - order - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OrderCreatedMultiStepCheckout {
    my ($hParams) = @_;

    my $Order = $hParams->{'Order'};

    my $LineItemContainer = $Order->container();
    return unless ( defined($LineItemContainer));

    my $LineItemPayment = $LineItemContainer->get('Payment');
    return unless ( defined($LineItemPayment));
    return unless ( $LineItemPayment->instanceOf(LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS));

    if ($LineItemPayment->get('TransStatus') eq PAYMENT_STATUS_PAID) {
        LogPayment(PAYMENT_TYPE_MOLLIE_PAYMENTS, 'In OrderCreatedMultiStepCheckout set Order PaidOn', {'OrderId' => $Order->id()});
        DE_EPAGES::MolliePayments::API::PaymentStatusService->setOrderStatusPaidTime($Order, $LineItemPayment->get('TransTime'));
    }

    return;
}

1;